==> haskell-apply-refact-0.11.0.0-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-apply-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 apply-refact
version:              0.11.0.0
visibility:           public
id:                   apply-refact-0.11.0.0-1P1eY1XxJ6G80294gqJA2d
key:                  apply-refact-0.11.0.0-1P1eY1XxJ6G80294gqJA2d
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
homepage:             https://github.com/mpickering/apply-refact
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  ba795de2c83f8526254c06b67861bae3
exposed:              True
exposed-modules:
    Refact.Apply Refact.Compat Refact.Fixity Refact.Internal
    Refact.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/apply-refact-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/apply-refact-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/apply-refact-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-apply-refact
hs-libraries:         HSapply-refact-0.11.0.0-1P1eY1XxJ6G80294gqJA2d
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    extra-1.7.16-Dogq4JQiVI0JTl9E7yM5k0
    filemanip-0.3.6.3-7K63b47rCLx4bJ8PAOFxDP ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-exactprint-1.6.1-GtUC2BEhO6sAEoVHv7kUUL
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj process-1.6.18.0
    refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA
    syb-0.7.2.4-2WyT1tb84OB9oN2LvYBzxO transformers-0.5.6.2
    uniplate-1.6.13-CtLx9PqmvWD1kB9CZ7AAO2
    unix-compat-0.7.3-J07jpPIGxfa51gt4vnZWxP

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-apply-refact-0.11.0.0-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-apply-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 apply-refact
version:              0.11.0.0
visibility:           public
id:                   apply-refact-0.11.0.0-5tNnpXki5193lb4q3l4Xq2
key:                  apply-refact-0.11.0.0-5tNnpXki5193lb4q3l4Xq2
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
homepage:             https://github.com/mpickering/apply-refact
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  72abff3b007413d59a1127fbeff0e2b8
exposed:              True
exposed-modules:
    Refact.Apply Refact.Compat Refact.Fixity Refact.Internal
    Refact.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/apply-refact-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/apply-refact-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/apply-refact-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-apply-refact
hs-libraries:         HSapply-refact-0.11.0.0-5tNnpXki5193lb4q3l4Xq2
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    extra-1.7.16-9yFW5HMy3QJKMvZBMWGOPz
    filemanip-0.3.6.3-1Au7VVHK37bLInlBMDbWZA ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-exactprint-1.6.1-94PTC7IWu9KDEIDOauj7Cn
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj process-1.6.18.0
    refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA
    syb-0.7.2.4-2WyT1tb84OB9oN2LvYBzxO transformers-0.5.6.2
    uniplate-1.6.13-INMUS7W6TvrLPoVHOvC85P
    unix-compat-0.7.3-KodBgNM0fPsEC9GAASBuc8

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
